rewrite_asset_references

Function rewrite_asset_references 

pub fn rewrite_asset_references(
    content: &str,
    served: &BTreeMap<AssetName, String>,
) -> String
content with the target of each reference to an asset served names replaced by the URL it maps to, and every other byte as it was.